Reference papers
================

A non-exhausted list of papers related to operator-valued kernels. Any dead links?
Open a new issue `here <https://github.com/RomainBrault/operalib/issues>`_.

* Reviews:
	- `Wikipedia entry <https://en.wikipedia.org/wiki/Reproducing_kernel_Hilbert_space>`_.
	- `Kernels for Vector-Valued Functions: a Review <http://cbcl.mit.edu/publications/ps/MIT-CSAIL-TR-2011-033.pdf>`_, Alvarez et al. 2011

* On operator-valued kernels:
	- `On learning vector-valued function <http://www0.cs.ucl.ac.uk/staff/M.Pontil/reading/vecval.pdf>`_, Micchelli et al. 2005.
	- `Kernels for Vector-Valued Functions: a Review <http://cbcl.mit.edu/publications/ps/MIT-CSAIL-TR-2011-033.pdf>`_, Alvarez et al. 2011
	- `Vector valued reproducing kernel Hilbert spaces of integrable functions and Mercer theorem <https://www.ge.infn.it/~gruppo4www/galilei/rkhs_vec.pdf>`_, Carmeli et al., 2006.

* Universal operator-valued kernels:
	- `Vector valued reproducing kernel Hilbert spaces and universality <https://www.ge.infn.it/~gruppo4www/galilei/CDTU_Universal.pdf>`_, Carmeli et al., 2008
	- `Universal Kernels for Multi-Task learning <http://www6.cityu.edu.hk/ma/doc/people/caponnettoa/universal(JP14).pdf>`_, Caponnetto et al., 2006.

* Classification:
	- `Multiclass Learning with Simplex Coding <http://arxiv.org/pdf/1209.1360v2.pdf>`_, Youssef Mroueh et al., 2012.

* Vector-field learning:
	- `Modeling magnetic fields using Gaussian processes <http://user.it.uu.se/~thosc112/pubpdf/wahlstromksg2013.pdf>`_, Wahlstrom et al., 2013.
	- `Learning divergence-free and curl-free vector fields with matrix-valued kernels <http://preprint.impa.br/FullText/Macedo__Thu_Oct_21_16_38_10_BRDT_2010/macedo-MVRBFs.pdf>`_, Macedo et al., 2010.



* Structured output prediction, link prediction:
	- `Input Output Kernel Regression <https://hal.archives-ouvertes.fr/hal-01216708/file/Input_Output_Kernel_Regression.pdf>`_, Brouard et al., 2015.
	- `A Generalized Kernel Approach to Structured Output Learning <http://arxiv.org/pdf/1205.2171.pdf>`_, Kadri et al., 2015.

* Multiple output kernels:
	- `Multiple Operator-valued Kernel Learning <http://papers.nips.cc/paper/4653-multiple-operator-valued-kernel-learning.pdf>`_, Kadri et al., 2011.

* Multiview/multitask learning:
	- `Learning Multiple Tasks with Kernel Methods <http://www.cs.berkeley.edu/~russell/classes/cs294/f05/papers/evgeniou+al-2005.pdf>`_, Evgeniou et al., 2005.
	- `A Unifying Framework for Vector-valued Manifold Regularization and Multi-view Learning <http://www.lorisbazzani.info/papers/proceedings/Minhetal_ICML13.pdf>`_, Quang Minh et al., 2013.

* Functional data:
	- `Operator-valued Kernels for Learning from Functional Response Data <http://www.grappa.univ-lille3.fr/~ppreux/papiers/Kadri-et-al.Operator-valued-Kernels-for-Learning-from-Functional-Response-Data.pdf>`_, Kadri et al., 2015.
	- `Nonlinear functional regression: a functional RKHS approach <http://jmlr.csail.mit.edu/proceedings/papers/v9/kadri10a/kadri10a.pdf>`_, Kadri et al., 2010.
	- `Operator-valued kernel recursive least squares algoritm <http://www.eurasip.org/Proceedings/Eusipco/Eusipco2015/papers/1570102849.pdf>`_, Amblard et al., 2015.

* Learning kernels:
	- `Learning low-rank output kernels <http://jmlr.csail.mit.edu/proceedings/papers/v20/dinuzzo11/dinuzzo11.pdf>`_, Dinuzzo et al., 2011.
	- `Learning Output Kernels with Block Coordinate Descent <http://www.icml-2011.org/papers/54_icmlpaper.pdf>`_, Dinuzzo et al., 2011.
	- `Operator-valued Kernel-based Vector Autoregressive Models for Network Inference <https://hal.archives-ouvertes.fr/hal-00872342v2/document>`_, Lim et al., 2014.

* Refinement of kernels:
	- `Refinement of Operator-valued Reproducing Kernels <http://www.jmlr.org/papers/volume13/zhang12a/zhang12a.pdf>`_, Zhang et al., 2012.

* Differential equations:
	- `Learning nonparametric differential equations with operator-valued kernels and gradient matching <http://arxiv.org/pdf/1411.5172v1.pdf>`_, Heinonen et al., 2014.

* Large scale-learning with operator-valued kernels:
	- `Online Learning with Multiple Operator-valued Kernels <http://arxiv.org/pdf/1311.0222.pdf>`_, Audiffren et al., 2013.
